/*********************************************************************************************

	WRITTEN BY: SETH MURRAY 
		 Generate the final CSV files used to produce the following tables and figures
		 in the paper

	FINAL OUTPUT:
	      - Figure 3(a): for_fig_F_top3_ind3.csv
	      - Figure 3(b): for_fig_F_top3_ind3_1995v2017.csv
	      - Figure 1(a) and 2(a-d): for_figs_fq_earn_gap.csv
	      - Figure 1(b): for_figs_fq_emp_gap.csv
	      - Figure 2(a-d): for_figs_fq_earn_gap.csv
	      - Table 1(A): top_earn_occupation_freqs.csv
	      - Table 1(B): top_earn_occupation_freqs_wt.csv 
*********************************************************************************************/

%include "config.sas";

%let outdir = /final;
%let supdir = /final/support;
%let figdatadir = /final/figures;

    
%macro gen_gap_fig_data(outcome, rnd_lvl);
* FQ Earn Gap - Baseline;
* ==============================================;
data tmp_out_base(keep=age estimate_base_rnd);
    set outputs.gen_fq_&outcome._gap_baseline;
    
    estimate_base_rnd = round(estimate,&rnd_lvl);
run;
    
data tmp_out_sup_base(keep=age estimate_base estimate_base_rnd);
    set outputs.gen_fq_&outcome._gap_baseline(rename=(estimate=estimate_base));
    
    estimate_base_rnd = round(estimate_base,&rnd_lvl);
run;    
    
* FQ Earn Gap - Number of Kids;
* ==============================================;
data tmp_out_ever(keep=age estimate_ever_rnd ptype);
    set outputs.gen_fq_&outcome._gap_evermom;
    where ptype ~= "M";
    
    estimate_ever_rnd = round(estimate,&rnd_lvl);
run;
    
data tmp_out_sup_ever(keep=age estimate_ever estimate_ever_rnd ptype);
    set outputs.gen_fq_&outcome._gap_evermom(rename=(estimate=estimate_ever));
    where ptype ~= "M";
    
    estimate_ever_rnd = round(estimate_ever,&rnd_lvl);
run;    
    
* FQ Earn Gap - Number of Kids - control age of child by birth order;
* ==============================================;
data tmp_out_ever_ctrl(keep=age estimate_ever_ctrl_rnd ptype);
    set outputs.gen_fq_&outcome._gap_evermom_ctrl;
    where ptype ~= "M";
    
    estimate_ever_ctrl_rnd = round(estimate,&rnd_lvl);
run;
    
data tmp_out_sup_ever_ctrl(keep=age estimate_ever_ctrl estimate_ever_ctrl_rnd ptype);
    set outputs.gen_fq_&outcome._gap_evermom_ctrl(rename=(estimate=estimate_ever_ctrl));
    where ptype ~= "M";
    
    estimate_ever_ctrl_rnd = round(estimate_ever_ctrl,&rnd_lvl);
run;    
    
  
*Combine the files;  
* ==============================================; 

* output files;
proc sort data= tmp_out_ever;
    by  age ptype;
run;
proc sort data=tmp_out_ever_ctrl;
    by age ptype;
run;

data tmp_combo1;
    merge tmp_out_ever
          tmp_out_ever_ctrl;
    by age ptype;
run;
    
data tmp_combo2;
    set tmp_out_base
        tmp_combo1;
run;
proc export data=tmp_combo2
            outfile="&figdatadir./for_figs_fq_&outcome._gap.csv"
            dbms=csv
            replace;
run; 
    
* support files;
proc sort data= tmp_out_sup_ever;
    by  age ptype;
run;
proc sort data=tmp_out_sup_ever_ctrl;
    by age ptype;
run;

data tmp_combo1;
    merge tmp_out_sup_ever
          tmp_out_sup_ever_ctrl;
    by age ptype;
run;
    
data tmp_combo2;
    set tmp_out_sup_base
        tmp_combo1;
run;
proc export data=tmp_combo2
            outfile="&supdir./for_figs_fq_&outcome._gap.csv"
            dbms=csv
            replace;
run;    
    


%if  "&outcome." = "emp" %then %do;        
* support file with counts;
data tmp_out(keep=age F_c_num emp_status count);
    set outputs.&outcome._gap_reg_counts;
    
run;
            
proc export data=tmp_out
            outfile="&supdir./for_fig_fq_&outcome._gap_counts.csv"
            dbms=csv
            replace;
run;
%end;

%if  "&outcome." ^= "emp" %then %do;        
* support file with counts;
data tmp_out(keep=age F_c_num count);
    set outputs.&outcome._gap_reg_counts;
    
run;
            
proc export data=tmp_out
            outfile="&supdir./for_fig_fq_&outcome._gap_counts.csv"
            dbms=csv
            replace;
run;
%end;

* Birth penalty;
* ==============================================;
data tmp_out(keep=birth_num y_since_birth estimate_rnd );
    set outputs.birth_penalty_fq_&outcome.;
    
    estimate_rnd = round(estimate,0.0001);
run;
            
proc export data=tmp_out
            outfile="&figdatadir./for_fig_fq_&outcome._birth_penalty.csv"
            dbms=csv
            replace;
run;

data tmp_out(keep=birth_num y_since_birth estimate_rnd estimate );
    set outputs.birth_penalty_fq_&outcome.;
    
    estimate_rnd = round(estimate,0.0001);
run;
            
proc export data=tmp_out
            outfile="&supdir./for_fig_fq_&outcome._birth_penalty.csv"
            dbms=csv
            replace;
run;

%if  "&outcome." = "emp" %then %do;
PROC CONTENTS DATA=outputs.&outcome._birth_penalty_reg_counts0;
RUN;

PROC CONTENTS DATA=outputs.&outcome._birth_penalty_reg_counts1;
RUN;

* support file with counts;
data tmp_out0 (keep=y_since_birth birth_num count_emp_status0);
    set outputs.&outcome._birth_penalty_reg_counts0;
    
    %do c = 1 %to 4;
        %do a = 1 %to 77;
            y_since_birth = (&a. - 5)/4;
            birth_num = &c.;
            count_emp_status0 = birth&c._a&a._sum;
            output;
        %end;
    %end;
run;

PROC SORT DATA=tmp_out0 NODUPKEY;
	BY y_since_birth birth_num;
RUN;

data tmp_out1 (keep=y_since_birth birth_num count_emp_status1);
    set outputs.&outcome._birth_penalty_reg_counts1;
    
    %do c = 1 %to 4;
        %do a = 1 %to 77;
            y_since_birth = (&a. - 5)/4;
            birth_num = &c.;
            count_emp_status1 = birth&c._a&a._sum;
            output;
        %end;
    %end;
run;

PROC SORT DATA=tmp_out1 NODUPKEY;
	BY y_since_birth birth_num;
RUN;

DATA tmp_out;
	MERGE tmp_out0 tmp_out1;
	BY y_since_birth birth_num;
RUN;
%end;

%if  "&outcome." ^= "emp" %then %do;
data tmp_out (keep=y_since_birth birth_num count);
    set outputs.&outcome._birth_penalty_reg_counts;
    
    %do c = 1 %to 4;
        %do a = 1 %to 77;
            y_since_birth = (&a. - 5)/4;
            birth_num = &c.;
            count = birth&c._a&a._sum;
            output;
        %end;
    %end;
run;
%end;
                       
proc export data=tmp_out
            outfile="&supdir./&outcome._birth_penalty_count.csv"
            dbms=csv
            replace;
run;
            
%mend;
    
%gen_gap_fig_data(earn,0.001);
%gen_gap_fig_data(emp,0.0001);


* Occupation Information;
* ===============================================;
%macro occupation_process(apply_wt);
data tmp_out(keep=count pct_col pct_col_rnd sex occ_type earn_threshold count_total);
    length earn_threshold $5;
    set outputs.occtype_freq_top1&apply_wt. (in=in_top1)
        outputs.occtype_freq_top3&apply_wt. (in=in_top3)
        outputs.occtype_freq_p99&apply_wt. (in=in_p99)
        outputs.occtype_freq_p95&apply_wt. (in=in_p95)
        outputs.occtype_freq_p90&apply_wt. (in=in_p90);
    where occ_type = "Exec or Manager" or occ_type = "Professional" or occ_type = "Supervisor";
    
    if in_top1 then earn_threshold = "Top 1";
    if in_top3 then earn_threshold = "Top 3";
    if in_p99 then earn_threshold = "P99";
    if in_p95 then earn_threshold = "P95";
    
    if in_p90 then do;
        if is_p90_fq_earn = 0 then earn_threshold = "<P90";
        else if is_p90_fq_earn =  1 then earn_threshold = "P90";
        else if is_p90_fq_earn = . then delete;
    end;
    pct_col_rnd = round(pct_col,0.01);
        
    count_total = round(count/(0.01*pct_col),1);
run;

proc sort data=tmp_out;
    by earn_threshold sex;
run;
    
data tmp_count(keep= earn_threshold sex implicit_count);
    set tmp_out;
    by earn_threshold sex;
    retain implicit_count;
    
    if first.sex then implicit_count = count_total;
    
    implicit_count = implicit_count - count;
    
    if last.sex then output;
run;
    
data tmp_out2;
    merge tmp_out
          tmp_count;
    by earn_threshold sex;
run;
            
proc export data=tmp_out2(drop=count pct_col count_total implicit_count)
            outfile="&outdir./top_earn_occupation_freqs&apply_wt..csv"
            dbms=csv
            replace;
run;
        
proc export data=tmp_out2
            outfile="&supdir./top_earn_occupation_freqs&apply_wt..csv"
            dbms=csv
            replace;
run;
%mend;
%occupation_process(); 
%occupation_process(_wt);     

        
        
* Freq Occupation is in top X;
* ===============================================;

data tmp_out(keep=fsz occ_type sex earn_type count percent percent_rnd count_total);
    length earn_type $5;
    set outputs.in_top3_freq_occ (in=in_top3);

    if fsz = "" then delete; 

    if is_top3_fq_earn = 0 then earn_type  = "<Top3" ;
    if is_top3_fq_earn = 1 then earn_type  = "Top3" ;

 
    percent_rnd = round(percent,0.01);
        
    count_total = round(count/(0.01*percent),1);
run;

proc export data=tmp_out
            outfile="&supdir./freq_occupation_top_earn.csv"
            dbms=csv
            replace;
run; 

data tmp_out1(keep=fsz occ_type sex earn_type percent_rnd);
    set tmp_out;
    where earn_type ~= "<Top3";
run;
            
proc export data=tmp_out1 
            outfile="&outdir./freq_occupation_top_earn.csv"
            dbms=csv
            replace;
run;
        
   

* Evolution of Leadership Shares over Time;
* ===============================================;
data tmp_out(keep=earn_type percent percent_rnd count qtime);
    length earn_type $20;
    set outputs.f_shr_earner_qtime_wt  ;
    where 21 < qtime <= 131;

    earn_type = "top1_wt";
    percent = top1_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = top1_f_ratio_n;
    output;
    
    earn_type = "top3_wt";
    percent = top3_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = top3_f_ratio_n;
    output;

    earn_type = "p99_wt";
    percent = p99_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = p99_f_ratio_n;
    output;
    
    earn_type = "p95_wt";
    percent = p95_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = p95_f_ratio_n;
    output;
    
    earn_type = "p90_wt";
    percent = p90_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = p90_f_ratio_n;
    output;

    earn_type = "f_m_fqearn_ratio";
    percent = f_m_avg_fqearn_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = f_m_avg_fqearn_ratio_n;
    output;
    
   
  
run;
              
          
proc export data=tmp_out(keep=qtime earn_type percent_rnd)
            outfile="&figdatadir./for_fig_top_f_shr_over_time.csv"
            dbms=csv
            replace;
run;
        
proc export data=tmp_out
            outfile="&supdir./for_fig_top_f_shr_over_time.csv"
            dbms=csv
            replace;
run;                      

                    
* Overall top Leadership shares - some weighted by employment;
* ========================================;  
data tmp_out(keep=earn_type percent percent_rnd count count_unweighted);
    length earn_type $20;
    set outputs.f_shr_earner_wt (in=in_wt  )
        outputs.f_shr_earner (in=in_unwt) ;
    
  if in_wt then do;
    earn_type = "top1_wt";
    percent = top1_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = top1_f_ratio_n;
    output;
    
    earn_type = "top3_wt";
    percent = top3_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = top3_f_ratio_n;
    output;

    earn_type = "p99_wt";
    percent = p99_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = p99_f_ratio_n;
    output;
    
    earn_type = "p95_wt";
    percent = p95_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = p95_f_ratio_n;
    output;
    
    earn_type = "p90_wt";
    percent = p90_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = p90_f_ratio_n;
    output;

    earn_type = "f_m_fqearn_ratio";
    percent = f_m_avg_fqearn_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = f_m_avg_fqearn_ratio_n;
    output;
  end;
  if in_unwt then do;
    earn_type = "top1";
    percent = top1_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = top1_f_ratio_n;
    output;
    
    earn_type = "top3";
    percent = top3_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = top3_f_ratio_n;
    output;

    earn_type = "p99";
    percent = p99_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = p99_f_ratio_n;
    output;
    
    earn_type = "p95";
    percent = p95_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = p95_f_ratio_n;
    output;
    
    earn_type = "p90";
    percent = p90_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = p90_f_ratio_n;
    output;

    earn_type = "bp90";
    percent = bp90_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = bp90_f_ratio_n;
    output;
    
    earn_type = "all_emp";
    percent = allemp_f_ratio_mean;
    percent_rnd = round(percent,0.001);
    count = allemp_f_ratio_n;
    output;
    
    output;
  end;
run;

   
          
proc export data=tmp_out(keep= earn_type percent_rnd)
            outfile="&outdir./top_f_shr.csv"
            dbms=csv
            replace;
run;
        
proc export data=tmp_out
            outfile="&supdir./top_f_shr.csv"
            dbms=csv
            replace;
run;                      
                    

                    
* 1995 vs 2017 3-digit industry comparison;
* ========================================;                                       
data tmp_out;
    set outputs.f_shr_earner_ind3_95v17_wt;
    where industry_3d ~= "" and industry_3d ~= "927" and industry_3d ~= "482";
                 
    
    top3_F_ratio_1995_rnd = round(top3_F_ratio_1995,0.001);
    top3_F_ratio_2017_rnd = round(top3_F_ratio_2017,0.001);
    chg_top3_F_ratio_17v95_rnd = top3_F_ratio_2017_rnd - top3_F_ratio_1995_rnd;
    f_m_avg_fqearn_ratio_1995_rnd = round(f_m_avg_fqearn_ratio_1995,0.001);
    f_m_avg_fqearn_ratio_2017_rnd = round(f_m_avg_fqearn_ratio_2017,0.001);
    chg_f_m_avg_fqearn_17v95_rnd = f_m_avg_fqearn_ratio_2017_rnd - f_m_avg_fqearn_ratio_1995_rnd;

run;
                    
          
proc export data=tmp_out(keep= chg_top3_F_ratio_17v95_rnd chg_f_m_avg_fqearn_17v95_rnd industry_3d )
            outfile="&figdatadir./for_fig_F_top3_ind3_1995v2017.csv"
            dbms=csv
            replace;
run;
        
proc export data=tmp_out(keep=chg_top3_F_ratio_17v95_rnd chg_f_m_avg_fqearn_17v95_rnd top3_F_ratio_1995_rnd top3_F_ratio_2017_rnd industry_3d top3_F_ratio_1995 top3_F_ratio_2017 f_m_avg_fqearn_ratio_1995_rnd f_m_avg_fqearn_ratio_2017_rnd f_m_avg_fqearn_ratio_1995 f_m_avg_fqearn_ratio_2017 count_fm_ratio_1995 count_fm_ratio_2017 count_top3_1995 count_top3_2017 )
            outfile="&supdir./for_fig_F_top3_ind3_1995v2017.csv"
            dbms=csv
            replace;
run;                      
                           
* 3-digit industry comparison - full sample;
* ========================================;                                       
data tmp_out;
    set outputs.f_shr_earner_ind3_wt;
    where industry_3d ~= "" and top3_F_ratio_mean ~= . and industry_3d ~= "927" and industry_3d ~= "482";
                 
    
    top3_F_ratio_rnd = round(top3_F_ratio_mean,0.001);
    f_m_avg_fqearn_ratio_rnd = round(f_m_avg_fqearn_ratio_mean,0.001);

run;
                    
          
proc export data=tmp_out(keep=  top3_F_ratio_rnd f_m_avg_fqearn_ratio_rnd industry_3d )
            outfile="&figdatadir./for_fig_F_top3_ind3.csv"
            dbms=csv
            replace;
run;
        
proc export data=tmp_out(keep= top3_F_ratio_rnd top3_F_ratio_mean f_m_avg_fqearn_ratio_rnd f_m_avg_fqearn_ratio_mean  industry_3d top3_f_ratio_n f_m_avg_fqearn_ratio_n )
            outfile="&supdir./for_fig_F_top3_ind3.csv"
            dbms=csv
            replace;
run;                      
                    
