/*********************************************************************************************

	WRITTEN BY: MATTHEW STAIGER
		Identifies whether a given PIK appears in a given ACS survey year from 2001-
		2017, the 2000 Decennial Census, and/or the 2010 Decennial Census.
	
	OUTPUT DATASET: pikscenacs
	       VARIABLES: pik cen2000 cen2010 acs2001-acs2017
	
*********************************************************************************************/

*2000 DECENNIAL CENSUS;
*-----------------------------------------------------------------------*;
%macro cen00data;
*summarize input data;
PROC CONTENTS DATA=cenx00.census_2000_pik_xwalk_dwh;
RUN;

PROC CONTENTS DATA=cen00.cen2000hdf_or_03;
RUN;

*create national decennial file;
DATA cen00;	
	SET cen00.cen2000hdf_ak_03(OBS=&sample_size. 
		KEEP=puid pnc qrel qdb
		RENAME=(puid=mafid) );
RUN;

%let statelist = al ar az ca co ct dc de fl ga hi ia id il in ks ky la ma md
	me mi mn mo ms mt nc nd ne nh nj nm nv oh ok or pa pr ri sc sd tn tx ut 
	va vt wa wi wv wy;
%let length=%sysfunc(countw(&statelist.));
%DO i=1 %TO &length.;
%let st=%scan(&statelist.,&i.);
DATA cen00;	
	SET cen00
		cen00.cen2000hdf_&st._03(OBS=&sample_size. 
			KEEP=puid pnc qrel qdb
			RENAME=(puid=mafid) );
RUN;
%END;

*there should be no duplicates here;
PROC SORT DATA=cen00(WHERE=(mafid^="")) NODUPKEY;
	BY mafid pnc;
RUN;

*there should by no duplicates here;
PROC SORT DATA=cenx00.census_2000_pik_xwalk_dwh(OBS=&sample_size.  
		KEEP=mafid pnc pik) 
		OUT=xwalk NODUPKEY;
	BY mafid pnc;
RUN;

DATA cen00(KEEP=pik qrel WHERE=(pik^=""));
	MERGE cen00(IN=source_cen00) xwalk(IN=source_xwalk KEEP=mafid pnc pik);
	BY mafid pnc;
	IF source_cen00^=1 OR source_xwalk^=1 THEN DELETE;
RUN;

*drop missing or duplicate piks;
PROC SORT DATA=cen00 OUT=cen00 DUPOUT=dups(KEEP=pik) NODUPKEY;
	BY pik;
RUN;

PROC SORT DATA=dups NODUPKEY;
	BY pik;
RUN;

DATA cen00(KEEP=pik cen2000);
	LENGTH cen2000 3.;
	MERGE cen00(IN=source_cen00) dups(IN=source_dups);
	BY pik;
	IF source_cen00^=1 OR source_dups=1 
		OR (qrel^='01' AND qrel^='02') THEN DELETE;
	cen2000=1;
RUN;

PROC SORT DATA=cen00 OUT=interwrk.pikscenacs NODUPKEY;
	BY pik;
RUN;

*delete all data in work library to free up memory;
PROC DATASETS LIBRARY=WORK KILL NOLIST;
RUN;

%mend cen00data;
%cen00data;

*ACS DATA;
*-----------------------------------------------------------------------*;
%macro acsdata;

%let acsdata2001 = vpers2001_1yr;
%let acsdata2002 = vpers2002_1yr;
%let acsdata2003 = vpers2003_1yr;
%let acsdata2004 = vpers2004_1yr;
%let acsdata2005 = vpers2005_1yr;
%let acsdata2006 = vpers2006_1yr;
%let acsdata2007 = vpers2007_1yr;
%let acsdata2008 = vpers2008_1yr;
%let acsdata2009 = vpers2009_1yr;
%let acsdata2010 = vpers2010_1yr;
%let acsdata2011 = vpers2011_1yr;
%let acsdata2012 = vpers2012_1yr;
%let acsdata2013 = vpers2013_1yr;
%let acsdata2014 = vpers2014_1yr;
%let acsdata2015 = vpers2015_1yr;
%let acsdata2016 = acs2016_vpers_1yr;
%let acsdata2017 = acs2017_vpers_1yr;

%DO yr=2001 %TO 2017;

*summarize input data;
PROC CONTENTS DATA=acs&yr..&&acsdata&yr;
RUN;

PROC CONTENTS DATA=acsx&yr..crosswalk_acs&yr.;
RUN;

*there should be no duplicates here;
PROC SORT DATA=acs&yr..&&acsdata&yr(OBS=&sample_size. 
		KEEP=cmid pnum rel dbd dbm dby)
		OUT=acs 
		NODUPKEY;
	BY cmid pnum;
RUN;

PROC SORT DATA=acsx&yr..crosswalk_acs&yr.(OBS=&sample_size.)
		OUT=acsxwalk
		NODUPKEY;
	BY cmid pnum;
RUN;

DATA acs(KEEP=pik rel WHERE=(pik^=""));
	LENGTH pnum 8;
	MERGE acs(IN=source_acs) acsxwalk(IN=source_xwalk);
	BY cmid pnum;
	IF source_acs^=1 OR source_xwalk^=1  THEN DELETE;
	rel=COMPRESS(rel);
RUN;

*drop parents with duplicates piks;
PROC SORT DATA=acs OUT=parents DUPOUT=dups(KEEP=pik) NODUPKEY;
	BY pik;
RUN;

PROC SORT DATA=dups NODUPKEY;
	BY pik;
RUN;

DATA parents(KEEP=pik acs&yr.);
	LENGTH acs&yr. 3.;
	MERGE parents(IN=source_sample) dups(IN=source_dups);
	BY pik;
	IF source_sample^=1 OR source_dups=1
		OR (rel^='0' AND rel^='1') THEN DELETE;
	acs&yr.=1;
RUN;

DATA interwrk.pikscenacs;
	MERGE interwrk.pikscenacs parents;
	BY pik;
RUN;

PROC SORT DATA=interwrk.pikscenacs OUT=interwrk.pikscenacs NODUPKEY;
	BY pik;
RUN;

*delete all data in work library to free up memory;
PROC DATASETS LIBRARY=WORK KILL NOLIST;
RUN;
%END;

%mend acsdata;
%acsdata;

*2010 DECENNIAL CENSUS;
*-----------------------------------------------------------------------*;
%macro cen10data;

*summarize input files;
PROC CONTENTS DATA=cen10.cen2010hdf_us_p;
RUN;

PROC CONTENTS DATA=cenx10.cuf_2010_enh1_crosswalk;
RUN;

*attach PIKs to decennial file;
DATA cen10;	
	LENGTH carra_uid $21;
	SET cen10.cen2010hdf_us_p(OBS=&sample_size. 
		KEEP=mafid cuf_pnc qrel colblkst qdb);
	carra_uid = CATT('',colblkst,mafid,"0000",cuf_pnc);
RUN;

*there should be no duplicates;
PROC SORT DATA=cen10 NODUPKEY;
	BY carra_uid;
RUN;

PROC SORT DATA=cenx10.cuf_2010_enh1_crosswalk(OBS=&sample_size. ) OUT=xwalk NODUPKEY;
	BY carra_uid;
RUN;

DATA cen10(KEEP=pik qrel WHERE=(pik^=""));
	MERGE cen10(IN=source_cen10) xwalk(IN=source_xwalk KEEP=carra_uid pik);
	BY carra_uid;
	IF source_cen10^=1 OR source_xwalk^=1 THEN DELETE;
RUN;

*drop missing or duplicate piks;
PROC SORT DATA=cen10 OUT=cen10 DUPOUT=dups(KEEP=pik) NODUPKEY;
	BY pik;
RUN;

PROC SORT DATA=dups NODUPKEY;
	BY pik;
RUN;

DATA cen10(KEEP=pik cen2010);
	LENGTH cen2010 3.;
	MERGE cen10(IN=source_cen10) dups(IN=source_dups);
	BY pik;
	IF source_cen10^=1 OR source_dups=1 
		OR (qrel^="01" AND qrel^="02") THEN DELETE;
	cen2010=1;		
RUN;

DATA interwrk.pikscenacs;
	MERGE interwrk.pikscenacs cen10;
	BY pik;
	IF cen2000^=1 THEN cen2000=0;
	IF cen2010^=1 THEN cen2010=0;
	%DO yr=2001 %TO 2017;
		IF acs&yr.^=1 THEN acs&yr.=0;
	%END;
RUN;


PROC SORT DATA=interwrk.pikscenacs OUT=interwrk.pikscenacs NODUPKEY;
	BY pik;
RUN;

*delete all data in work library to free up memory;
PROC DATASETS LIBRARY=WORK KILL NOLIST;
RUN;

%mend cen10data;
%cen10data;

*SUMMARIZE FINAL DATASET WITH ALL SOURCES;
*-----------------------------------------------------------------------*;
%macro finaldata;

PROC FREQ DATA=interwrk.pikscenacs;
	TITLE "tabulate surveys that piks appears in";
	TABLES cen2000 cen2010 acs2001-acs2017 /MISSING;
RUN;

PROC CONTENTS DATA=interwrk.pikscenacs;
RUN;

PROC PRINT DATA=interwrk.pikscenacs(OBS=100);
RUN;

%mend finaldata;
%finaldata;
