/*********************************************************************************************

	WRITTEN BY: SETH MURRAY
		Identifies the QTIME of any changes in persistent top earner changes from one
		PIK to another PIK at a given SEIN.  For each transition QTIME, keeps track of
		the PIKs of both the new and old top earners, as well as the tenure (as of the
		time of the transition) of the new top earner and the sex composition of the
		new and old top earners.

	OUTPUT DATASET: interwrk.top_earner_transitions
*********************************************************************************************/


%let num_obs = max;
%let max_num_sein = 200;

proc sort data=interwrk.sein_top_earner_pik;
    by sein qtime;
run;
    
* remove duplicates;
data tmp_top_earner_nodups /view=tmp_top_earner_nodups;
    set interwrk.sein_top_earner_pik;
    by sein qtime;
  
    if first.qtime and last.qtime then output;
run;

* Same for the forward looking top earner;
proc sort data=interwrk.sein_top_earner_fwd_pik;
    by sein qtime;
run;
    
* remove duplicates;
data tmp_top_earner_fwd_nodups /view=tmp_top_earner_fwd_nodups;
    set interwrk.sein_top_earner_fwd_pik;
    by sein qtime;
  
    if first.qtime and last.qtime then output;
run;
    
* identify firms where the peristent top earner changes;
data top_earner_changes(
                        keep=top_pik_bck top_pik_fwd top_pik_fwd_dob top_pik_bck_dob transition_qtime transition_sex sein);
    length transition_qtime 3 top_pik_fwd top_pik_bck $9 transition_sex $2 top_pik_fwd_dob top_pik_bck_dob 4;
    merge tmp_top_earner_nodups
          tmp_top_earner_fwd_nodups (rename=(pik=pik_fwd sex=sex_fwd dob=dob_fwd));
    by sein qtime;
    retain first_sein_qtime;
    
    array top_earner_pik {&last_qtime.} $9 _temporary_;
    array top_earner_fwd_pik {&last_qtime.} $9 _temporary_;
    array top_earner_dob {&last_qtime.} 4 _temporary_;
    array top_earner_fwd_dob {&last_qtime.} 4 _temporary_;
    array fq_emp_count {&last_qtime.} _temporary_;
    array top_earner_sex {&last_qtime.} $9 _temporary_;
    array top_earner_fwd_sex {&last_qtime.} $9 _temporary_;
    
    if first.sein then do;
        first_sein_qtime = qtime;
        do i = &first_qtime. to &last_qtime.;
            top_earner_pik{i} = "";
            top_earner_fwd_pik{i} = "";
            top_earner_dob{i} = "";
            top_earner_fwd_dob{i} = "";
            fq_emp_count{i} = .;
            top_earner_sex{i} = "";
            top_earner_fwd_sex{i} = "";
        end;
    end;
         
    top_earner_pik{qtime} = pik;
    top_earner_fwd_pik{qtime} = pik_fwd;
    top_earner_dob{qtime} = dob;
    top_earner_fwd_dob{qtime} = dob_fwd;
    fq_emp_count{qtime} = fq_earn_4qma_n;
    top_earner_sex{qtime} = sex;
    top_earner_fwd_sex{qtime} = sex_fwd;
            
    if last.sein then do;
        last_sein_qtime = qtime;
        if first_sein_qtime < last_sein_qtime - 2*&min_top_earn_tenure. - 2 then do;
            do qtime = first_sein_qtime + &min_top_earn_tenure. to last_sein_qtime - &min_top_earn_tenure. - 2;
                * identify transitions;
                if top_earner_pik{qtime} ~= top_earner_fwd_pik{qtime+2} and 
                        top_earner_pik{qtime} ~= "" and 
                        top_earner_fwd_pik{qtime+2} ~= "" then do;
                    * check if each individual is the top earner for at least 2 years;
                    top_earner_bck_ten = 0;
                    top_earner_fwd_ten = 0;
                    do i = 1 to &min_top_earn_tenure.;
                        if top_earner_pik{qtime} = top_earner_pik{qtime-i} then top_earner_bck_ten = top_earner_bck_ten + 1;
                        if top_earner_fwd_pik{qtime+2} = top_earner_fwd_pik{qtime+i+1} then top_earner_fwd_ten = top_earner_fwd_ten + 1;
                    end;
                        
                    if top_earner_bck_ten >= &min_top_earn_tenure. - 1 and top_earner_fwd_ten >= &min_top_earn_tenure. -1  then do;
                        transition_qtime = qtime+1;
                        transition_sex = catt(top_earner_sex{qtime},top_earner_fwd_sex{qtime+2});
                        top_pik_bck = top_earner_pik{qtime};
                        top_pik_fwd = top_earner_fwd_pik{qtime+2};
                        top_pik_bck_dob = top_earner_dob{qtime};
                        top_pik_fwd_dob = top_earner_fwd_dob{qtime+2};
                        
                        if fq_emp_count{qtime} > &min_trans_emp_thres. and fq_emp_count{qtime+2} > &min_trans_emp_thres. then output;
                    end;
                
                end;
            end;
        end;
    end;
run;

proc  sort data=top_earner_changes;
    by sein  transition_qtime;
run;

* ==================================================================================================;
* ==================================================================================================;
* identify whether the tenure of the new top earner and whether employed in other firm at same alpha;
* ==================================================================================================;
* ==================================================================================================;
data tmp_ecf_w_qtime (keep=sein qtime firmid) /view=tmp_ecf_w_qtime ;
    length qtime 3;
    set lehd_t26.ecf_interleave_sein_t26 (keep=sein year quarter firmid);
    
    qtime = (year-1985)*4+quarter;
run;
    
proc sort data=tmp_ecf_w_qtime
          out=tmp_ecf_w_qtime_srt;
    by sein qtime;
run;
    
* get the firm id of the sein employing the new top earner;
data tmp_top_new(drop=rc qtime rename=(firmid=transition_firmid));
    length firmid $10 qtime 3;
    merge top_earner_changes (in=in_top keep=sein transition_qtime top_pik_fwd rename=(top_pik_fwd=pik))
          tmp_ecf_w_qtime_srt (in=in_ecf rename=(qtime=transition_qtime));
    by sein transition_qtime;
    
    if in_top then output;
run;
    

* get the earnings of the new top earner;                        
data top_earner_phf;
    set lehd_t13.phf_interleave_b (obs=&num_obs. keep=pik fid sein e21-e&last_qtime.);
    where pik ~= "000000000";
    
      
    if _n_ = 1 then do;
    
        declare hash top_earner_h (dataset:"tmp_top_new",hashexp:16,multidata:'Y');
            top_earner_h.defineKey('pik');
            top_earner_h.defineDone();
  
    end;
    
    rc = top_earner_h.check();
    if rc = 0 then output;
run;
        
proc sort data=top_earner_phf;
    by pik sein ;
run;
    
data new_top_earner_char
                (keep = pik sein transition_qtime transition_firmid transition_type in_prev_qtime new_mngr_tenure_bck) ;
    length transition_firmid $10 transition_qtime 3 e1-e20 5 transition_type $2 qtime 3 in_prev_qtime 3 new_mngr_tenure_bck 3;
    set top_earner_phf;
    by pik sein ;
    retain sein_counter;
    
    array alpha_set {&max_num_sein.,&last_qtime.} $10 _temporary_;
    array sein_set {&max_num_sein.} $12 _temporary_;
    array earn_hist {&max_num_sein., &last_qtime.} _temporary_;
            
    array earn {&last_qtime.} e1-e&last_qtime.;
            
    if _n_ = 1 then do;
        declare hash firm_char_h (dataset:"tmp_ecf_w_qtime_srt",hashexp:16);
            firm_char_h.defineKey("sein","qtime");
            firm_char_h.defineData("firmid");
            firm_char_h.defineDone();
           
        declare hash top_earner_sein_h (dataset:"tmp_top_new",hashexp:16,multidata:'Y');
            top_earner_sein_h.defineKey('pik','sein');
            top_earner_sein_h.defineData('transition_qtime','transition_firmid');
            top_earner_sein_h.defineDone();
        
    end;
    
    if first.pik then do;
        sein_counter = 0;
        do i = 1 to &max_num_sein.;
            sein_set{i} = "";
        
            do j = &first_qtime. to &last_qtime.;
                alpha_set{i,j} = "";
                earn_hist{i,j} = 0;
            end;
        end;
    end;
                
    if sein_counter < &max_num_sein. then do;
        sein_counter = sein_counter + 1;
        sein_set{sein_counter} = sein;
            
        do qtime = &first_qtime. to &last_qtime.;
            rc = firm_char_h.find();
            if rc = 0 then do;
                alpha_set{sein_counter,qtime} = firmid; 
            end;
            earn_hist{sein_counter,qtime} = earn{qtime};
        end;
    end;
    
    if last.pik then do;
        
        do s = 1 to sein_counter;
            * check if this is a firm at which the worker became a persistent top earner;
            sein = sein_set{s};
            rc = top_earner_sein_h.find();
            do while(rc=0);
                in_prev_qtime = 0;
                transition_type = "";
                            
                new_mngr_tenure_bck = 0;
                
                label transition_type = "HN = new sein and new firmid, HS = new sein same firmid, SS = same sein";
                * check for which firm employed the individual previously (look two quarters back to avoid transitions starting in previous quarter;;
                do i = 1 to sein_counter;
                    * if same firm;
                    if s = i then do;
                        if earn_hist{i,transition_qtime-2} > 0 then do;
                            transition_type = "SS";
                            do j = 2 to 20;
                                if earn_hist{i,transition_qtime-j} > 0 then new_mngr_tenure_bck = j;
                            end;
                        end;
                        else do;
                            if earn_hist{i,transition_qtime-1} > 0 then do;
                                in_prev_qtime = 1;
                            end;
                                
                            if substr(transition_type,2,1) = "S" then transition_type = "HS";
                            else transition_type = "HN";
                        end;
                    end;
                    
                    * if other firm;
                    if s ~= i then do;
                        if earn_hist{i,transition_qtime-2} > 0 then do;
                            if alpha_set{i,transition_qtime-2} = transition_firmid and transition_firmid ~= "" then substr(transition_type,2,1) = "S"; 
                        end;
                    end;
                end;
                output;
                                           
                    
                rc = top_earner_sein_h.find_next();
            end;
        
        end;
    
    end;
            
    
        
run;
    
proc sort data=top_earner_changes;
    by sein top_pik_fwd transition_qtime;
run;
proc sort data=new_top_earner_char;
    by sein pik transition_qtime;
run;
    
    
data interwrk.top_earner_transitions;
    merge top_earner_changes (in=in_trans)
          new_top_earner_char(in=in_type rename=(pik=top_pik_fwd));
    by sein top_pik_fwd transition_qtime;
    
    if first.top_pik_fwd then output;
run;       



proc sort data=interwrk.top_earner_transitions nodupkey;
    by sein top_pik_fwd;
run;

                          
                                
proc contents data=interwrk.top_earner_transitions;
proc print data=interwrk.top_earner_transitions(obs=50);

proc freq data=interwrk.top_earner_transitions;
    table transition_type transition_qtime in_prev_qtime transition_sex transition_sex*transition_type new_mngr_tenure_bck*transition_sex /missing;
run;
