/*********************************************************************************************

	WRITTEN BY: SETH MURRAY
		 For each parent in the dataset, extract their earnings history forward and back 5 years at their dominant employer as of the time of the childbirth event.

	OUTPUT DATASETS:
		- interwrk.ACS_parent_earning_hist
*********************************************************************************************/

    
%let max_n_fid = 200;
%let num_obs = max;
    
%let worker_type = ACS_parent;
                    
%let min_yr_after_last_birth = 3;


* Identify parents first and last birth qtime;

proc sort data=interwrk.parentchild;
    by pik birth_qtime;
run;
    
data &worker_type._frst_lst_birth (keep=pik first_birth_qtime last_birth_qtime final_acs_year);
    length first_birth_qtime last_birth_qtime 3 final_acs_year 4;
    set interwrk.parentchild;
    by pik birth_qtime;
    retain first_birth_qtime;
        
    array acs_survey {18} acs2001-acs2018;

    
    if first.pik then first_birth_qtime = birth_qtime;
    if last.pik then do;
        last_birth_qtime = birth_qtime;
        last_birth_year = floor((qtime-1)/4)+1985;
        
        * keeping only individuals from the ACS, surveyed as least 3 years after last child;

            * only output if ever in the ACS;
            if sum(of acs_survey[*]) > 0 then do;
                * determine last year in the ACS;
                do i = 1 to 18;
                    if acs_survey{i} = 1 then final_acs_year = 2000 + i;
                end;
                * if this is before the 2010 dicennial and the person is in the 2010 dicennial, then use 2010;
                if cen10 = 1 and final_acs_year < 2010 and final_acs_year >= 2000 then final_acs_year = 2010;
                    
                if last_birth_year + &min_yr_after_last_birth. < final_acs_year then output;
               
            end;

    end;
    
run;

* generate parent only version of phf;
     
data parents_phf(drop=rc);
    length final_acs_year 4;
    set lehd_t13.phf_interleave_b (obs=&num_obs. keep=pik fid sein e21-e&last_qtime.);
    where pik ~= "000000000";         
    
    if _n_ = 1 then do;
            declare hash parents_h (dataset:"acs_parent_frst_lst_birth",hashexp:16);
                parents_h.defineKey('pik');
                parents_h.defineData('final_acs_year');
                parents_h.defineDone();
    end;
    
    rc = parents_h.find();
    if rc = 0 then output;
run;
    
    
proc sort data=parents_phf;
    by pik fid;
run;

proc print data=parents_phf (obs = 5);

data interwrk.&worker_type._earning_hist(keep=pik dom_fid dom_fid_bck4 dom_sein dom_sein_bck4 birth_qtime earn_fq earn_total 
                           earn_fq_fwd1-earn_fq_fwd20 earn_total_fwd1-earn_total_fwd20
                           earn_fq_bck1-earn_fq_bck20 earn_total_bck1-earn_total_bck20
                           tenure_bck emp_at_dom_fid_fwd1-emp_at_dom_fid_fwd20
                           birth_order marital_status PIK_partner mafid first_birth_qtime last_birth_qtime final_acs_year);
    length e1-e20 earn_fq earn_total 5 dom_sein dom_sein_bck4 $12 
           tenure_bck emp_at_dom_fid_fwd1-emp_at_dom_fid_fwd20 3
           birth_qtime 3 birth_order 3 marital_status $1 pik_partner mafid $9 hh_head $1 first_birth_qtime last_birth_qtime 3;
    set parents_phf;
    by pik fid;
    retain n_fid too_many_fid;

    array earn {&last_qtime.} e1-e&last_qtime.;
    
    array earn_by_fid {&max_n_fid., &last_qtime.} _temporary_;
    array fqearn_by_fid {&max_n_fid., &last_qtime.} _temporary_;
    array sein_list {&max_n_fid., &last_qtime.} $12 _temporary_;
                            
    array fid_list{&max_n_fid.} 5 _temporary_;                        
    
    array earn_tot {&last_qtime.} _temporary_;
    array dom_fqearn_lvl {&last_qtime.} _temporary_;
    array fid_dom {&last_qtime.} 5 _temporary_;
                                       
    array earn_fq_fwd {20} 5;
    array earn_fq_bck {20} 5;
    array earn_total_fwd {20} 5;
    array earn_total_bck {20} 5;
    
    array emp_at_dom_fid_fwd {20} 3;                        
            
    if _n_ = 1 then do;
        n_fid = 1;     
                    
        declare hash parents_h (dataset:"interwrk.parentchild",hashexp:16,multidata:'Y');
            parents_h.defineKey('pik');
            parents_h.defineData('birth_qtime','birth_order','marital_status','pik_partner', 'mafid', 'hh_head');
            parents_h.defineDone();


        declare hash birth_range_h (dataset:"&worker_type._frst_lst_birth",hashexp:16);
            birth_range_h.defineKey('pik');
            birth_range_h.defineData('first_birth_qtime','last_birth_qtime');
            birth_range_h.defineDone();
    end;
    
    if first.pik then do;
        
        do i = &first_qtime. to &last_qtime.;
            dom_fqearn_lvl{i} = .;
            fid_dom{i} = .;
            earn_tot{i} = 0;
            do j = 1 to n_fid;
                earn_by_fid{j,i} = .;
                fqearn_by_fid{j,i} = .;
                sein_list{j,i} = "";
            end;
        
        end;
                
        do j = 1 to n_fid;
            fid_list{j} = .;     
        end;
        n_fid = 1;
        too_many_fid = 0;
    
    end;
    else if first.fid and n_fid < &max_n_fid. then do;
        if n_fid < &max_n_fid. then do;
            n_fid = n_fid + 1;      
        end;
        else too_many_fid = 1;
    end;
            
    fid_list{n_fid} = fid;
                
    * accumulate earnings across the SEIN associated with the fid;            
    do qt = &first_qtime. to &last_qtime.;
         if earn{qt} > 0 then do;
            earn_by_fid{n_fid,qt} = sum(earn{qt},earn_by_fid{n_fid,qt} );
            sein_list{n_fid,qt} = sein;
            earn_tot{qt} = earn_tot{qt} + earn{qt};                           
         end;                                   
    end;
    
    * identify full-quarter earnings;
    if last.fid  then do;                        
        do qt = &first_qtime. to &last_qtime. - 1;
            if earn_by_fid{n_fid,qt} > 0 then do;
                * if full quarter earnings across all sein for this fid;
                if earn_by_fid{n_fid,qt-1} > 0 and earn_by_fid{n_fid,qt+1} > 0 then do;
   
                    fqearn_by_fid{n_fid,qt} = earn_by_fid{n_fid,qt};
                    * check if this is the dominant earnings;
                    if earn_by_fid{n_fid,qt} > dom_fqearn_lvl{qt} then do;
                        fid_dom{qt} = fid;
                        dom_fqearn_lvl{qt} = earn_by_fid{n_fid,qt};
                    end;
                end;
            end;   
        end;                    
    end;
                    
    if last.pik = 1 and too_many_fid = 0 then do;


        rc_fst_lst = birth_range_h.find();
           
        rc = parents_h.find(); *****;
        do while(rc=0);         
          if &first_qtime.  < birth_qtime < &last_qtime.  then do;
            tenure_bck = .;
            dom_fid = .;
            dom_fid_bck4 = .;
            dom_sein = "";
            dom_sein_bck4 = ""; ******;
            earn_fq = .;
            earn_total = .;
            do i = 1 to 20;
                earn_fq_fwd{i} = .;
                earn_fq_bck{i} = .;
                earn_total_fwd{i} = .;
                earn_total_bck{i} = .;
                emp_at_dom_fid_fwd{i} = .;
            end;
                            
            * identify the dominant sein at the birth time (from the dominant fid);
            dom_fid = fid_dom{birth_qtime};
            dom_fid_bck4 = fid_dom{birth_qtime -4};                
            do i = 1 to n_fid;
                if dom_fid = fid_list{i} then dom_sein = sein_list{i,birth_qtime};
                if dom_fid_bck4 = fid_list{i} then dom_sein_bck4 = sein_list{i,birth_qtime-4};     
            end;
                        
            * calculate the dominant full-quarter earnings and total earnings +/- 20 quarters fwd and bck from one year before birth;                
            earn_fq = dom_fqearn_lvl{birth_qtime - 4};
            earn_total = earn_tot{birth_qtime - 4};
            do i = 1 to 20;
                if birth_qtime -4 + i < &last_qtime. then do;
                    earn_fq_fwd{i} = dom_fqearn_lvl{birth_qtime-4+i};
                    earn_total_fwd{i} = earn_tot{birth_qtime-4+i};
                end;
                else do;
                    earn_fq_fwd{i} = .;
                    earn_total_fwd{i} = .;
                end;
                    
                if birth_qtime - i - 4 > &first_qtime. then do;
                    earn_fq_bck{i} = dom_fqearn_lvl{birth_qtime-4-i};
                    earn_total_bck{i} = earn_tot{birth_qtime-4-i};
                end;
                else do;
                    earn_fq_bck{i} = .;
                    earn_total_bck{i} = .;
                end;
            end;
            
            * calculate tenure back and employment status fwd at the dominant employer 1 year before birth;
            do i = 1 to n_fid;
                if fid_list{i} = dom_fid_bck4 and dom_fid_bck4 ~= . then do;
                    if birth_qtime - 4 <= &first_qtime. then tenure_bck = .;
                    else do;
                        tenure_bck = 0;
                        do j = 1 to birth_qtime - 4 - &first_qtime.;
                            if earn_by_fid{i,birth_qtime-j-4} > 0 then tenure_bck = tenure_bck + 1;
                        end;
                    
                        do j = 1 to 20;
                            if birth_qtime - 4 + j < &last_qtime. then do;
                                if earn_by_fid{i,birth_qtime -4 + j} > 0 then emp_at_dom_fid_fwd{j} = 1;
                                else emp_at_dom_fid_fwd{j} = 0;
                            end;
                            else do;
                                emp_at_dom_fid_fwd{j} = .;
                            end;
                        end;
                    end;         
                end;
            end;

            label tenure_bck = "Workers tenure at dominant SEIN one year before birth (qtime-4)"
                  emp_at_dom_fid_fwd1 = "=1 if worker has positive earnings at dominant employer in birth_qtime-4 one quarter later (= birth_qtimee -3)"
                  dom_sein = "dominant employer SEIN in birth_qtime"
                  dom_sein_bck4 = "dominant employer SEIN in birth_qtime - 4 (used to calculate tenuree and emp variables)";
            
            *require at least 4 quarters of tenure at the dominant employer as of 1 year before birth;
            if tenure_bck >=4 then output;
           
          end;
            
            rc = parents_h.find_next();
        end;     
    end;

run;  

proc contents data=interwrk.&worker_type._earning_hist;
proc print data=interwrk.&worker_type._earning_hist(obs=100);                        

