/*********************************************************************************************

	WRITTEN BY: SETH MURRAY & MATT STAIGER
		 Identifies coworkers at mothers' employers who are employed at the same firm
		 4 quarters before birth, surveyed in the ACS at least 3 years after the birth
		 quarter, and in the same age range as potential parents.  Extracts these
		 coworkers' earnings histories.  From these coworkers, generate a matched
		 sample based on pre-birth earnings level and earnings growth rates, race/
		 ethnicity, education, sex, year-of-birth, and pre-birth tenure.

	OUTPUT DATASETS:
		- interwrk.coworker_earning_hist
*********************************************************************************************/
        
%let max_n_fid = 200;                
%let num_obs = max;                

%macro earn_hist;

* ============================================;
* STATE SUBSET;
* ============================================;
data states_to_include;
    set lehd_t13.stateyq_w_ecf_02102019;     
    
    if start_year = &first_year_reg. then do;
        if start_quarter = &first_quarter_reg. then output;
    end;
    else if start_year < &first_year_reg. then output;
run;
        
proc print data=states_to_include;
    
* ============================================;
* Identify SEINs of mothers to try to match;
* ============================================;

DATA mother_dom_sein;
	SET interwrk.acs_parent_earning_hist(KEEP=pik dom_sein_bck4 birth_qtime birth_order)
		interwrk.mngr_tr_earning_hist(KEEP=pik transition_sein birth_qtime birth_order
			RENAME=(transition_sein=dom_sein_bck4));
RUN;

proc sort data=mother_dom_sein OUT=mother_dom_sein(DROP=birth_order) NODUPKEY;
    by pik birth_order;
run;
        
DATA mother_dom_sein(drop=pik);
    MERGE mother_dom_sein(IN=in_sample)
		lehd_t13.icf_us(keep=pik sex in=in_icf);
	BY pik;
	IF in_sample^=1 THEN DELETE;
RUN;

data mother_dom_sein(drop=sex rc fipscode);
    length fipscode $2;	
	set mother_dom_sein(keep=dom_sein_bck4 birth_qtime sex);
	
	if _n_ = 1 then do;
        declare hash state_fips_h (dataset:"states_to_include");
            state_fips_h.defineKey('fipscode');
            state_fips_h.defineDone();
        
    end;
    
    * only keep mothers;
    if sex = "F" then do;
        * only keep if in the target states;
        fipscode = substr(dom_sein_bck4,1,2);
        rc = state_fips_h.check();
        if rc = 0 then output;
    end;
	
run;

proc sort data=mother_dom_sein NODUPKEY;
    by dom_sein_bck4 birth_qtime;
run;

proc contents data=mother_dom_sein;

* ============================================;
* Identify first and last birth qtime for ALL parents (not just those in the target universe);
* ============================================;
    
data any_parent_frst_lst_birth (keep=pik first_birth_qtime last_birth_qtime);
    length first_birth_qtime last_birth_qtime 3 last_survey_year 4;
    set interwrk.parentchild;
    by pik birth_qtime;
    retain first_birth_qtime;
        
    array acs_survey {18} acs2001-acs2018;

    
    if first.pik then first_birth_qtime = birth_qtime;
    if last.pik then do;
        last_birth_qtime = birth_qtime;
        
        output;
    end;
    
run;
        
proc sort data=any_parent_frst_lst_birth;
    by pik;
run;
                        
    
    

* ============================================;
* identify coworkers who are ;
*     1) female or male, ;
*     2) in the correct age range,; 
*     3) employed at the same firm 4 quarters before birth, and;
*     4) surveyed in the ACS at least three years after the birth quarter;
* ============================================;
        
        
data temp_last_survey_year (keep=pik last_survey_year);
    length last_survey_year 4;
    set interwrk.pikscenacs;
    
    array acs_survey {18} acs2001-acs2018;
    
    do i = 1 to 18;
        if acs_survey{i} = 1 then last_survey_year = 2000 + i;
        
        if last_survey_year < 2010 and cen2010 = 1 then last_survey_year = 2010;
        else if last_survey_year = . and cen2000 = 1 then last_survey_year = 2000;
    end;
        
    if last_survey_year ~= . then output;
run;
    
   
data coworker_set_init (keep=pik dom_sein_bck4 birth_qtime educ_c_imputed educ_c last_survey_qtime sex);
    length birth_qtime 3 dob 4 sex $1 sex_imputed $1 educ_c $1 educ_c_imputed $1 e1-e20 5 dom_sein_bck4 $12 last_survey_year 4;
    set lehd_t13.phf_interleave_b (obs=&num_obs.);
    where pik ~= "000000000";    
            
    array earn {&last_qtime.} e1-e&last_qtime. ;
    
    if _n_ = 1 then do;
    
        declare hash parent_employer_h (dataset:"mother_dom_sein",hashexp:16,multidata:'Y');
            parent_employer_h.defineKey('dom_sein_bck4');
            parent_employer_h.defineData('birth_qtime');
            parent_employer_h.defineDone();
        
        declare hash sex_age_h (dataset:"lehd_t13.icf_us",hashexp:16);
            sex_age_h.defineKey('pik');
            sex_age_h.defineData('dob','sex','sex_imputed','dob_imputed','educ_c_imputed','educ_c');
            sex_age_h.defineDone();
    
        declare hash survey_pik_h (dataset:"temp_last_survey_year",hashexp:16);
            survey_pik_h.DefineKey('pik');
            survey_pik_h.DefineData('last_survey_year');
            survey_pik_h.DefineDone();
    
    end;
        
    is_parent_employer = 0;
     
    dom_sein_bck4 = sein;
    rc = parent_employer_h.check();
    if rc = 0 then is_parent_employer = 1;
 
    if is_parent_employer = 1 then do;
        rc_sex = sex_age_h.find();
        if rc_sex = 0 then do;
            * dob not imputed;
            if dob_imputed = "1" then do;
                        
                * check if in correct age range at birth_qtime and employed at SEIN in birth qtime - 4;
                rc = parent_employer_h.find();
                do while(rc=0);
                    * check if full-quarter employed 4 quarters before birth qtime with 1 year of tenure;
                    if earn{birth_qtime - 4} > 0 and earn{birth_qtime-5}>0 and earn{birth_qtime-3} > 0 and earn{birth_qtime-6} > 0 and earn{birth_qtime - 7} > 0 then do;
                    
                        * check if in correct age range at birth qtime;
                        year = floor((birth_qtime-1)/4) + 1985;
                        quarter = birth_qtime - (year - 1985)*4;
                        if quarter = 1 then do;
                            q_st_date = mdy(1,1,year);
                            q_end_date = mdy(3,31,year);
                        end;
                        else if quarter = 2 then do;
                            q_st_date = mdy(4,1,year);
                            q_end_date = mdy(6,30,year);
                        end;
                        else if quarter = 3 then do;
                            q_st_date = mdy(7,1,year);
                            q_end_date = mdy(9,30,year);
                        end;
                        else if quarter = 4 then do;
                            q_st_date = mdy(10,1,year);
                            q_end_date = mdy(12,31,year);
                        end;
                        coworker_age_st_q = int(intck('MONTH', dob, q_st_date)/12) ;
                        coworker_age_end_q = int(intck('MONTH', dob, q_end_date)/12) ;
                    
                        * determine if between target age range at time of birth;
                        if &min_coworker_age. <= coworker_age_st_q
                            and &max_coworker_age. >= coworker_age_end_q then do;
            
							*if female make sure they are not mothers;
							if  sex = "F" and sex_imputed = "1"  then do;
								* check if individual was surveyed in the ACS or Census at least 3 years after birth_qtime;
								rc_survey = survey_pik_h.find();
								if rc_survey = 0 then do;
									last_survey_qtime = (last_survey_year-1985)*4 + 1;
									if birth_qtime + 12 < last_survey_qtime then output;                           
								end;
							end;
							*export all males;
							if  sex = "M" and sex_imputed = "1"  then output;
							
                        end;
                    end;
    
                    rc = parent_employer_h.find_next();    
                end;
            end;
        end;    
    end;
            
run;

* ============================================;
* Ensure the female coworkers did not give birth in a 2 year window around the birth date;
* ============================================;
    
proc sort data=coworker_set_init;
    by pik;
run;
    
data coworker_set;
    merge coworker_set_init (in=is_coworker)
          any_parent_frst_lst_birth (in=ever_parent);
    by pik;
    
    if is_coworker and sex="F" then do;
        if ever_parent then do;
            * coworker first gave birth at least 2 years after target parent;
            if first_birth_qtime > birth_qtime + 8 then output;
            * or coworker last gave birth 2 years before target parent;
            else if last_birth_qtime + 8 < birth_qtime and last_birth_qtime + 8 < last_survey_qtime then output;
    
        end;
        * if not a mother in dataset;
        else output;
    end;
	* if not a female output to coworker set;
    else output;
run;          
            
proc contents data=coworker_set;
proc print data=coworker_set(obs=20);   
            

proc sort data=coworker_set OUT=coworker_set_final  nodupkey;
    by pik birth_qtime dom_sein_bck4;
run;


data unique_coworker_piks(keep=pik);
    set coworker_set_final;
    by pik;
    
    if first.pik then output;
run;
    
         
data coworker_phf(drop=rc);
    set lehd_t13.phf_interleave_b (obs=&num_obs. keep=pik fid sein e21-e&last_qtime. );
    where pik ~= "000000000";         
    
    if _n_ = 1 then do;
    
        declare hash coworker_h (dataset:"unique_coworker_piks",hashexp:16);
            coworker_h.defineKey('pik');
            coworker_h.defineDone();
    
    end;
    
    rc = coworker_h.find();
    if rc = 0 then output;
run;
    
    
proc sort data=coworker_phf;
    by pik fid;
run;

proc contents data=coworker_phf;
proc print data=coworker_phf (obs = 5);
  
                        
                        

data interwrk.coworker_earning_hist(keep=pik dom_fid dom_fid_bck4 dom_sein dom_sein_bck4 birth_qtime earn_fq earn_total 
                           earn_fq_fwd1-earn_fq_fwd20 earn_total_fwd1-earn_total_fwd20
                           earn_fq_bck1-earn_fq_bck20 earn_total_bck1-earn_total_bck20
                           tenure_bck emp_at_dom_fid_fwd1-emp_at_dom_fid_fwd20 first_birth_qtime last_birth_qtime );
    length e1-e20 earn_fq earn_total 5 dom_sein dom_sein_bck4 $12 
           tenure_bck emp_at_dom_fid_fwd1-emp_at_dom_fid_fwd20 3
           birth_qtime 3 first_birth_qtime last_birth_qtime 3;
    set coworker_phf;
    by pik fid;
    retain n_fid too_many_fid;

    array earn {&last_qtime.} e1-e&last_qtime.;
    
    array earn_by_fid {&max_n_fid., &last_qtime.} _temporary_;
    array fqearn_by_fid {&max_n_fid., &last_qtime.} _temporary_;
    array sein_list {&max_n_fid., &last_qtime.} $12 _temporary_;
                            
    array fid_list{&max_n_fid.} 5 _temporary_;                        
    
    array earn_tot {&last_qtime.} _temporary_;
    array dom_fqearn_lvl {&last_qtime.} _temporary_;
    array fid_dom {&last_qtime.} 5 _temporary_;
                                       
    array earn_fq_fwd {20} 5;
    array earn_fq_bck {20} 5;
    array earn_total_fwd {20} 5;
    array earn_total_bck {20} 5;
    
    array emp_at_dom_fid_fwd {20} 3;                        
            
    if _n_ = 1 then do;
        n_fid = 1;     
                    
        declare hash birth_h (dataset:"coworker_set",hashexp:16,multidata:'Y');
            birth_h.defineKey('pik');
            birth_h.defineData('birth_qtime','dom_sein_bck4');
            birth_h.defineDone();
        
        declare hash birth_range_h (dataset:"any_parent_frst_lst_birth",hashexp:16);
            birth_range_h.defineKey('pik');
            birth_range_h.defineData('first_birth_qtime','last_birth_qtime');
            birth_range_h.defineDone();
    end;
    
    if first.pik then do;
        
        do i = &first_qtime. to &last_qtime.;
            dom_fqearn_lvl{i} = .;
            fid_dom{i} = .;
            earn_tot{i} = 0;
            do j = 1 to n_fid;
                earn_by_fid{j,i} = .;
                fqearn_by_fid{j,i} = .;
                sein_list{j,i} = "";
            end;
        
        end;
                
        do j = 1 to n_fid;
            fid_list{j} = .;     
        end;
        n_fid = 1;
        too_many_fid = 0;
    
    end;
    else if first.fid and n_fid < &max_n_fid. then do;
        if n_fid < &max_n_fid. then do;
            n_fid = n_fid + 1;      
        end;
        else too_many_fid = 1;
    end;
            
    fid_list{n_fid} = fid;
                
    * accumulate earnings across the SEIN associated with the fid;            
    do qt = &first_qtime. to &last_qtime.;
         if earn{qt} > 0 then do;
            earn_by_fid{n_fid,qt} = sum(earn{qt},earn_by_fid{n_fid,qt} );
            sein_list{n_fid,qt} = sein;
            earn_tot{qt} = earn_tot{qt} + earn{qt};                           
         end;                                   
    end;
    
    * identify full-quarter earnings;
    if last.fid  then do;                        
        do qt = &first_qtime. to &last_qtime. - 1;
            if earn_by_fid{n_fid,qt} > 0 then do;
                * if full quarter earnings across all sein for this fid;
                if earn_by_fid{n_fid,qt-1} > 0 and earn_by_fid{n_fid,qt+1} > 0 then do;
   
                    fqearn_by_fid{n_fid,qt} = earn_by_fid{n_fid,qt};
                    * check if this is the dominant earnings;
                    if earn_by_fid{n_fid,qt} > dom_fqearn_lvl{qt} then do;
                        fid_dom{qt} = fid;
                        dom_fqearn_lvl{qt} = earn_by_fid{n_fid,qt};
                    end;
                end;
            end;   
        end;                    
    end;
                    
    if last.pik = 1 and too_many_fid = 0 then do;
                    
        rc_fst_lst = birth_range_h.find();            
           
        rc = birth_h.find();
        do while(rc=0);         
          if &first_qtime.  < birth_qtime < &last_qtime.  then do;
            tenure_bck = .;
            dom_fid = .;
            dom_fid_bck4 = .;
            dom_sein = "";
            
            earn_fq = .;
            earn_total = .;
            do i = 1 to 20;
                earn_fq_fwd{i} = .;
                earn_fq_bck{i} = .;
                earn_total_fwd{i} = .;
                earn_total_bck{i} = .;
                emp_at_dom_fid_fwd{i} = .;
            end;
                            
            * identify the dominant sein at the birth time (from the dominant fid);
            dom_fid = fid_dom{birth_qtime};
            dom_fid_bck4 = fid_dom{birth_qtime -4};                
            do i = 1 to n_fid;
                if dom_fid = fid_list{i} then dom_sein = sein_list{i,birth_qtime};
                if dom_fid_bck4 = fid_list{i} then do;
                    dom_sein_bck4_act = sein_list{i,birth_qtime-4}; 
                end;    
            end;
            
            * check if this PIKs dominant employer one year prior to birth is the same as parents dominant employer;
            if dom_sein_bck4_act = dom_sein_bck4 then do;
                        
                * calculate the dominant full-quarter earnings and total earnings +/- 20 quarters fwd and bck from one year before birth;                
                earn_fq = dom_fqearn_lvl{birth_qtime - 4};
                earn_total = earn_tot{birth_qtime - 4};
                do i = 1 to 20;
                    if birth_qtime -4 + i < &last_qtime. then do;
                        earn_fq_fwd{i} = dom_fqearn_lvl{birth_qtime-4+i};
                        earn_total_fwd{i} = earn_tot{birth_qtime-4+i};
                    end;
                    else do;
                        earn_fq_fwd{i} = .;
                        earn_total_fwd{i} = .;
                    end;
                    
                    if birth_qtime - i - 4 > &first_qtime. then do;
                        earn_fq_bck{i} = dom_fqearn_lvl{birth_qtime-4-i};
                        earn_total_bck{i} = earn_tot{birth_qtime-4-i};
                    end;
                    else do;
                        earn_fq_bck{i} = .;
                        earn_total_bck{i} = .;
                    end;
                end;
            
                * calculate tenure back and employment status fwd at the dominant employer 1 year before birth;
                do i = 1 to n_fid;
                    if fid_list{i} = dom_fid_bck4 and dom_fid_bck4 ~= . then do;
                        if birth_qtime - 4 <= &first_qtime. then tenure_bck = .;
                        else do;
                            tenure_bck = 0;
                            do j = 1 to birth_qtime - 4 - &first_qtime.;
                                if earn_by_fid{i,birth_qtime-j-4} > 0 then tenure_bck = tenure_bck + 1;
                            end;
                    
                            do j = 1 to 20;
                                if birth_qtime - 4 + j < &last_qtime. then do;
                                    if earn_by_fid{i,birth_qtime -4 + j} > 0 then emp_at_dom_fid_fwd{j} = 1;
                                    else emp_at_dom_fid_fwd{j} = 0;
                                end;
                                else do;
                                    emp_at_dom_fid_fwd{j} = .;
                                end;
                            end;
                        end;         
                    end;
                end;
            
                

                label tenure_bck = "Workers tenure at dominant SEIN one year before birth (qtime-4)"
                    emp_at_dom_fid_fwd1 = "=1 if worker has positive earnings at dominant employer in birth_qtime-4 one quarter later (= birth_qtimee -3)"
                    dom_sein = "dominant employer SEIN in birth_qtime"
                    dom_sein_bck4 = "dominant employer SEIN in birth_qtime - 4 (used to calculate tenuree and emp variables)";
                    
                if first_birth_qtime = . and tenure_bck >=4 then output;
                else if ((birth_qtime > last_birth_qtime + 12) or (birth_qtime < first_birth_qtime - 12)) and tenure_bck >=4 then output;
     
            end;
          end;
            
            rc = birth_h.find_next();
        end;     
    end;

run;  

*there should be no duplicates here;
PROC SORT DATA=interwrk.coworker_earning_hist NODUPKEY;
	BY pik birth_qtime;
RUN;

proc contents data=interwrk.coworker_earning_hist;
proc print data=interwrk.coworker_earning_hist(obs=100);  

%mend earn_hist;

*LIMIT SAMPLE TO SIMILAR COWORKERS USING MATCHING;
*-------------------------------------------*;
%macro matching;

DATA coworker_match(KEEP=pik dom_sein_bck4 birth_qtime tenure_bck pre_earnings egrowth);
	SET interwrk.coworker_earning_hist(KEEP=pik dom_sein_bck4 birth_qtime tenure_bck
		earn_total earn_total_bck1-earn_total_bck7);
	e_t = earn_total+earn_total_bck1+earn_total_bck2+earn_total_bck3;
	e_tm1 = earn_total_bck4+earn_total_bck5+earn_total_bck6+earn_total_bck7;
	pre_earnings = log(e_t);
	egrowth = (e_t-e_tm1) / ( .5*(e_t+e_tm1) );
RUN;

PROC SORT DATA=coworker_match;
	BY pik;
RUN;

DATA mothers_match(KEEP=pik dom_sein_bck4 birth_qtime tenure_bck pre_earnings egrowth);
	SET interwrk.acs_parent_earning_hist(KEEP=pik dom_sein_bck4 birth_qtime tenure_bck
			earn_total earn_total_bck1-earn_total_bck7)
		interwrk.mngr_tr_earning_hist(KEEP=pik transition_sein birth_qtime tenure_bck
			earn_total earn_total_bck1-earn_total_bck7 RENAME=(transition_sein=dom_sein_bck4));
	e_t = earn_total+earn_total_bck1+earn_total_bck2+earn_total_bck3;
	e_tm1 = earn_total_bck4+earn_total_bck5+earn_total_bck6+earn_total_bck7;
	pre_earnings = log(e_t);
	egrowth = (e_t-e_tm1) / ( .5*(e_t+e_tm1) );
RUN;

proc sort data=mothers_match NODUPKEY;
    by pik birth_qtime;
run;
        
data coworker_match(KEEP=pik dom_sein_bck4 birth_qtime tenure_bck pre_earnings egrowth sex yob
		white black hispanic nohighschool highschool somecollege collegeplus educ_c mother);
    merge coworker_match (IN=source_earnigns)
          lehd_t13.icf_us(keep=pik sex dob educ_c educ_c_imputed ethnicity race in=source_icf);
    by pik;

		IF source_earnigns^=1 OR source_icf^=1 THEN DELETE;
		
		mother=0;
		white = 0;
		IF race="1" AND ethnicity^="H" THEN white=1;
		black = 0;
		IF race="2" AND ethnicity^="H" THEN black=1;
		hispanic = 0;
		IF ethnicity="H" THEN hispanic=1;
		yob = YEAR(dob);
		nohighschool = 0;
		IF educ_c_imputed="1" AND educ_c="1" THEN nohighschool = 1;
		highschool = 0;
		IF educ_c_imputed="1" AND educ_c="2" THEN highschool = 1;
		somecollege = 0;
		IF educ_c_imputed="1" AND educ_c="3" THEN somecollege = 1;
		collegeplus = 0;
		IF educ_c_imputed="1" AND educ_c="4" THEN collegeplus = 1;
		IF educ_c_imputed^="1" THEN educ_c=""; 
    
    if source_earnigns and source_icf then do;
        if &first_qtime_reg. + 8 <= birth_qtime <= &last_qtime_reg. - 8 then do;
            output coworker_match;
        end;
    end;
run;
		
data mothers_match(KEEP=pik dom_sein_bck4 birth_qtime tenure_bck pre_earnings egrowth sex yob
		white black hispanic nohighschool highschool somecollege collegeplus educ_c mother);
    merge mothers_match (IN=source_earnigns)
          lehd_t13.icf_us(keep=pik dob educ_c educ_c_imputed ethnicity race sex in=source_icf);
    by pik;

		IF source_earnigns^=1 OR source_icf^=1 THEN DELETE;
		
		mother=1;
		white = 0;
		IF race="1" AND ethnicity^="H" THEN white=1;
		black = 0;
		IF race="2" AND ethnicity^="H" THEN black=1;
		hispanic = 0;
		IF ethnicity="H" THEN hispanic=1;
		yob = YEAR(dob);
		nohighschool = 0;
		IF educ_c_imputed="1" AND educ_c="1" THEN nohighschool = 1;
		highschool = 0;
		IF educ_c_imputed="1" AND educ_c="2" THEN highschool = 1;
		somecollege = 0;
		IF educ_c_imputed="1" AND educ_c="3" THEN somecollege = 1;
		collegeplus = 0;
		IF educ_c_imputed="1" AND educ_c="4" THEN collegeplus = 1;
		IF educ_c_imputed^="1" THEN educ_c="";
    
	*retain mothers;
    if source_earnigns and source_icf and sex="F" then do;
        if &first_qtime_reg. + 8 <= birth_qtime <= &last_qtime_reg. - 8 then do;
            output mothers_match;
        end;
    end;

run;

*combine mother and coworker data to construct matched sample;
DATA matched;
	SET mothers_match coworker_match;
	coworker_f=0;
	IF sex="F" THEN coworker_f=1-mother;
	coworker_m=0;
	IF sex="M" THEN coworker_m=1-mother;
RUN;

PROC SORT DATA=matched;
	BY birth_qtime dom_sein_bck4;
RUN;

PROC MEANS DATA=matched NOPRINT;
	BY birth_qtime dom_sein_bck4;
	VAR mother coworker_f coworker_m;
	OUTPUT OUT=samplesize(KEEP=dom_sein_bck4 birth_qtime n_m n_cw_f n_cw_m)
		SUM(mother)=n_m
		SUM(coworker_f)=n_cw_f
		SUM(coworker_m)=n_cw_m;
RUN;

DATA matched(DROP=n_m n_cw_f n_cw_m coworker_f coworker_m);
	MERGE matched samplesize;
	BY birth_qtime dom_sein_bck4;
	*drop if no mothers;
	IF n_m=. OR n_m<=0 THEN DELETE;
	malecw_flag=0;
	IF (mother=1 OR (mother=0 AND sex="M"))
		AND n_m^=. AND n_m>0 AND n_cw_m^=. AND n_cw_m>=n_m THEN malecw_flag=1;
	femalecw_flag=0;
	IF (mother=1 OR (mother=0 AND sex="F"))
		AND n_m^=. AND n_m>0 AND n_cw_f^=. AND n_cw_f>=n_m THEN femalecw_flag=1;
RUN;

PROC FREQ DATA=matched;
	TABLES malecw_flag femalecw_flag sex /MISSING;
RUN;

*find nearest neighbors of female coworkers;
PROC LOGISTIC DATA=matched(WHERE=(femalecw_flag=1)) NOPRINT;
	BY birth_qtime;
	CLASS mother dom_sein_bck4 birth_qtime;
	MODEL  mother(event='1')=pre_earnings egrowth tenure_bck yob white black hispanic 
		highschool somecollege collegeplus;
	OUTPUT OUT=femalecw p=ps;
RUN;

ODS GRAPHICS OFF;
ODS EXCLUDE ALL;
PROC PSMATCH DATA=femalecw(KEEP=pik dom_sein_bck4 birth_qtime 
		mother pre_earnings egrowth tenure_bck yob white black hispanic 
		highschool somecollege collegeplus sex femalecw_flag ps) 
		REGION=ALLOBS;
	BY birth_qtime;
	CLASS mother dom_sein_bck4 birth_qtime;
	PSDATA TREATVAR=mother(Treated='1') ps=ps;;
	MATCH METHOD=greedy(k=1) 
		STAT=mah(var=(pre_earnings egrowth tenure_bck yob white black hispanic 
		highschool somecollege collegeplus)) 
		EXACT=dom_sein_bck4 
		CALIPER=.;
	OUTPUT OUT(OBS=match)= femalecw(KEEP=pik dom_sein_bck4 birth_qtime matchid mother femalecw_flag)  
		matchid=matchid;
RUN;

ODS EXCLUDE NONE;

*find nearest neighbors of male coworkers;
PROC LOGISTIC DATA=matched(WHERE=(malecw_flag=1)) NOPRINT;
	BY birth_qtime;
	CLASS mother dom_sein_bck4 birth_qtime;
	MODEL  mother(event='1')=pre_earnings egrowth tenure_bck yob white black hispanic 
		highschool somecollege collegeplus;
	OUTPUT OUT=malecw p=ps;
RUN;

ODS GRAPHICS OFF;
ODS EXCLUDE ALL;
PROC PSMATCH DATA=malecw(KEEP=pik dom_sein_bck4 birth_qtime 
		mother pre_earnings egrowth tenure_bck yob white black hispanic 
		highschool somecollege collegeplus sex malecw_flag ps) 
		REGION=ALLOBS;
	BY birth_qtime;
	CLASS mother dom_sein_bck4 birth_qtime;
	PSDATA TREATVAR=mother(Treated='1') ps=ps;
	MATCH METHOD=greedy(k=1) 
		STAT=mah(var=(pre_earnings egrowth tenure_bck yob white black hispanic 
		highschool somecollege collegeplus)) 
		EXACT=dom_sein_bck4 
		CALIPER=.;
	OUTPUT OUT(OBS=match)= malecw(KEEP=pik dom_sein_bck4 birth_qtime matchid malecw_flag mother)  
		matchid=matchid;
RUN;

ODS EXCLUDE NONE;

DATA matchedcw;
	SET malecw femalecw;
RUN;

*there should be no duplicates here;
PROC SORT DATA=matchedcw NODUPKEY;
	BY dom_sein_bck4 birth_qtime matchid malecw_flag femalecw_flag mother;
RUN;

DATA matchedcw(KEEP=pik dom_sein_bck4 birth_qtime pik_mother);
	MERGE matchedcw(IN=source_cw RENAME=(mother=mother_cw) WHERE=(mother_cw=0))
		matchedcw(IN=source_m KEEP=dom_sein_bck4 birth_qtime matchid pik mother
			malecw_flag femalecw_flag RENAME=(pik=pik_mother) WHERE=(mother=1));
	BY dom_sein_bck4 birth_qtime matchid malecw_flag femalecw_flag;
	IF source_cw^=1 OR source_m^=1 THEN DELETE;
RUN;

*there should be no duplicates here;
PROC SORT DATA=matchedcw NODUPKEY;
	BY pik birth_qtime;
RUN;
	
DATA interwrk.coworker_earning_hist;
	MERGE interwrk.coworker_earning_hist(IN=source_coworker)
		matchedcw(IN=source_matched);
	BY pik birth_qtime;
	IF source_coworker^=1 OR source_matched^=1 THEN DELETE;
RUN;

PROC CONTENTS DATA=interwrk.coworker_earning_hist;
RUN;

PROC PRINT DATA=interwrk.coworker_earning_hist(obs=20);
RUN;
    
*delete unneeded datasets;
PROC DATASETS LIBRARY=temp;
	DELETE matched mothers_match coworker_match matchedcw malecw femalecw;
RUN;

%mend matching;

%earn_hist;
%matching;
