/*********************************************************************************************

	WRITTEN BY: SETH MURRAY 
		 Constructs datasets for all identified parents, parents at manager transitions,
		 and their coworkers--where the datasets include the workers' earnings histories,
		 worker characteristics, and firm characteristics.

	OUTPUT DATASETS:
		- interwrk.sein_characteristics
		- interwrk.coworker_earn_plus_demo_bck4
		- interwrk.ACS_parent_earn_plus_demo_bck4
		- interwrk.mngr_tr_earn_plus_demo_bck4
*********************************************************************************************/

           

    
* Merge SEIN Characteristics;
proc sort data=interwrk.sein_top_earner_thresholds;
    by sein qtime;
run;
    
data tmp_ecf_t26 /view=tmp_ecf_t26;
    set lehd_t26.ecf_interleave_sein_t26;
    
    qtime = (year - 1985)*4 + quarter;
run;

proc sort data=tmp_ecf_t26
          out=tmp_ecf_t26_sorted;
    by sein qtime;
run;

data interwrk.sein_characteristics(drop=_missing)
     merge_stats(keep=_missing);
    length _missing $21;
    merge lehd_t13.ecf_interleave_sein_t13(keep=sein qtime mode_naics2017fnl_emp num_estabs rename=(mode_naics2017fnl_emp=naics) in=in_t13)
          tmp_ecf_t26_sorted(keep=sein qtime fas_ein firmage firmsize firmid in=in_t26)
          interwrk.sein_top_earner_thresholds (in=in_mngr);
    by sein qtime;
          
    if in_t13 = 0 then _missing = catt(_missing," ecf_t13");
    if in_t26 = 0 then _missing = catt(_missing," ecf_t26");
    if in_mngr = 0 then _missing = catt(_missing," mngr");
    output merge_stats;
    
    output interwrk.sein_characteristics;
run;

proc freq data=merge_stats;
    table _missing;
run;
    
proc contents data=interwrk.sein_characteristics;
proc print data=interwrk.sein_characteristics (obs=20);
    

* Merge Worker Earnings and Worker/Firm Characteristics;    

%macro merge_worker_firm_char(ind_type);

proc sort data=interwrk.&ind_type._earning_hist;
    by pik;
run;
        
* Merge worker earnings and demographic variables;
data tmp_merge (drop=_merge )
     merge_stats(keep=_merge birth_qtime);
    merge interwrk.&ind_type._earning_hist (in=in_phf)
          lehd_t13.icf_us(keep=pik dob dob_imputed educ_c educ_c_imputed ethnicity ethnicity_imputed race race_imputed sex sex_imputed in=in_icf);
    by pik;
        
    _merge = in_phf + 2* in_icf;
    output merge_stats;
    
    if in_phf and in_icf then do;
        if &first_qtime_reg. + 4 <= birth_qtime <= &last_qtime_reg. - 8 then do;
            output tmp_merge;
        end;
    end;
    
run;


        
proc freq data=merge_stats;
    table _merge _merge*birth_qtime;
run;
    

    
* Merge Worker Earnings and Worker/Firm Characteristics at birth_qtime-4;   

%if "&ind_type." = "mngr_tr" %then %do;
    proc sort data=tmp_merge;
        by transition_sein transition_qtime;
    run;
       
    
    data interwrk.&ind_type._earn_plus_demo_bck4(drop=_merge)
        merge_stats(keep=_merge);
        merge tmp_merge (in=in_phf )
            interwrk.sein_characteristics(in=in_ecf rename=(qtime=transition_qtime sein=transition_sein));
        by transition_sein transition_qtime;
          
        _merge = in_phf + 2 * in_ecf;
        output merge_stats;
    
        if in_phf and transition_sein ~= "" then output interwrk.&ind_type._earn_plus_demo_bck4;
    run;
    
%end;
%else %do;    
    proc sort data=tmp_merge;
        by dom_sein_bck4 birth_qtime;
    run;
    
    data tmp_merge_tm4 /view=tmp_merge_tm4;
        set tmp_merge;
    
        birth_qtime_bck4 = birth_qtime - 4;
    run;
    
    data interwrk.&ind_type._earn_plus_demo_bck4(drop=_merge)
        merge_stats(keep=_merge);
        merge tmp_merge_tm4 (in=in_phf )
            interwrk.sein_characteristics(in=in_ecf rename=(qtime=birth_qtime_bck4 sein=dom_sein_bck4));
        by dom_sein_bck4 birth_qtime_bck4;
          
        _merge = in_phf + 2 * in_ecf;
        output merge_stats;
    
        if in_phf and dom_sein_bck4 ~= "" then output interwrk.&ind_type._earn_plus_demo_bck4;
    run;
    
%end;
    


proc freq data=merge_stats;
    table _merge;
run;


proc sort data=interwrk.&ind_type._earn_plus_demo_bck4;
    by pik birth_qtime;
run;
    
proc contents data=interwrk.&ind_type._earn_plus_demo_bck4;
proc print data=interwrk.&ind_type._earn_plus_demo_bck4(obs=20);


%if "&ind_type." = "coworker" %then %do;
* Remove the parents from the coworker file in the birth_qtime in which they give birth;

data interwrk.coworker_earn_plus_demo_bck4;
    merge interwrk.coworker_earn_plus_demo_bck4
          interwrk.parent_earn_plus_demo_bck4 (in=in_parent keep=pik birth_qtime);
    by pik birth_qtime;
    
    if in_parent then delete;
run;
%end;
    

%mend;

%merge_worker_firm_char(acs_parent);
%merge_worker_firm_char(coworker);
%merge_worker_firm_char(mngr_tr);



    
    

