/*********************************************************************************************

	WRITTEN BY: SETH MURRAY 
		 Generates the earnings history (and full-quarter earnings history) for all individuals for which we can determine if they were ever parents.

	OUTPUT DATASETS:
	       	- interwrk.ever_parent_earning_hist
		- interwrk.ever_parent_earnfq_hist
		- interwrk.ever_parent_ear_fq_hist_stcnt
		- outputs.ever_parent_earn_fq_stcnt 
*********************************************************************************************/

    
%let num_obs = MAX;

* generate parent only version of phf;
     
data parents_phf(drop=rc);
    set lehd_t13.phf_interleave_b (obs=&num_obs. keep=pik fid sein e21-e&last_qtime.);
    where pik ~= "000000000";         
    
    if _n_ = 1 then do;
            declare hash parents_h (dataset:"interwrk.ever_parent",hashexp:16);
                parents_h.defineKey('pik');
                parents_h.defineDone();
    end;
    
    rc = parents_h.check();
    if rc = 0 then output;
run;
    
    
proc sort data=parents_phf;
    by pik fid;
run;

proc sort data=interwrk.ever_parent;
    by pik;
run;

proc print data=parents_phf (obs = 5);

data interwrk.ever_parent_earning_hist(keep=pik earn_r_age72-earn_r_age300 birth_qtr birth_yr birth_qt sex ever_parent race sex educ_c ethnicity c_birth_age1-c_birth_age10 n_children )
    interwrk.ever_parent_earnfq_hist(keep=pik earn_fq_r_age72-earn_fq_r_age300 birth_qtr birth_yr birth_qt sex ever_parent race sex educ_c ethnicity c_birth_age1-c_birth_age10 n_children )
    interwrk.ever_parent_earn_fq_hist_stcnt(keep=sein_state);
    length e1-e20  n_children 3 sein_state $2;
    merge parents_phf
          interwrk.ever_parent(obs=&num_obs.)
                
          lehd_t13.icf_us(obs=&num_obs. keep=pik dob_imputed educ_c educ_c_imputed ethnicity ethnicity_imputed race race_imputed sex_imputed in=in_icf);
    by pik;
	
	sein_state = SUBSTR(sein,1,2);

    array earn {&last_qtime.} e1-e&last_qtime.;
            
    array earn_fq {&last_qtime.} _temporary_;
    array earn_r_fq  {&last_qtime.};
            
    array b_qt {10} b_qtime1-b_qtime10;
                
    array earn_r_tot {&last_qtime.} ;                          
    array earn_tot {&last_qtime.} _temporary_;
                                       
    array earn_r_age {300} 5;
    array earn_fq_r_age {300} 5;
                
    array c_birth_age {10} 4;
        
            
    if _n_ = 1 then do;
        declare hash cpi_data (dataset:"inputs.cpi");
            cpi_data.defineKey("qtime");
            cpi_data.defineData("cpi_adjustment");
            cpi_data.defineDone();
    end;
                            
    if first.pik then do;
        do i = &first_qtime. to &last_qtime.;
            earn_tot{i} = 0;
            earn_fq{i} = 0;
        end;
    end;
        
    * accumulate earnings;           
    do qt = &first_qtime. to &last_qtime.;
         if earn{qt} > 0 then earn_tot{qt} = earn_tot{qt} + earn{qt};              
    end;
    
    * identify maximum full-quarter earnings;
    do qt = &first_qtime. + 1 to &last_qtime. - 1;
         if earn{qt} > 0 and earn{qt-1} > 0 and earn{qt+1}  > 0 then do;
            if earn_fq{qt} < earn{qt} then earn_fq{qt} = earn{qt};
            
            output interwrk.ever_parent_earn_fq_hist_stcnt;
         end;               
    end;
            
    if last.pik then do;
        if educ_c_imputed ~= "1" then educ_c = "U";
        if ethnicity_imputed ~= "1" then ethnicity = "U";
        if race_imputed ~= "1" then race = "U";
        if sex_imputed ~= "1" then sex = "U";
                
        * calculate birth information;        
        birth_qtr = qtr(dob);
        birth_yr = year(dob);
        birth_qt = (birth_yr - 1985)*4 + birth_qtr;
                
        
        if 1964  <= birth_yr < 2000 then do;    
            * calculate the number of children;
            n_children = 0;
            do i = 1 to 10;
                if b_qt{i} ~= . then n_children = n_children + 1;
            end;
                
            do qtime = &first_qtime. to &last_qtime.;
                * convert to real;
                rc = cpi_data.find();
                if rc = 0 and earn_tot{qtime} > 0 then do;
                    earn_r_tot{qtime} = earn_tot{qtime} * cpi_adjustment;
                end;
            
                if rc = 0 and  earn_fq{qtime} > 0 then do;
                    earn_r_fq{qtime} =  earn_fq{qtime}  *  cpi_adjustment;
                end;
            
                * calculate earnings by age;    
                age_in_qtrs = qtime - birth_qt;
                
                earn_r_age{age_in_qtrs} = earn_r_tot{qtime};
                earn_fq_r_age{age_in_qtrs} = earn_r_fq{qtime};
            end;
                        
            * identify the individuals age(s) at each birth;
            if n_children > 0 then do;
                do i = 1 to n_children;
                    c_birth_age{i} = b_qt{i} - birth_qt; 
                end;
            end;
                
                
            output interwrk.ever_parent_earning_hist;
            output interwrk.ever_parent_earnfq_hist;

        end;
    end;

run;  

proc contents data=interwrk.ever_parent_earning_hist;
proc print data=interwrk.ever_parent_earning_hist(obs=100);   
                    
proc contents data=interwrk.ever_parent_earnfq_hist;
proc print data=interwrk.ever_parent_earnfq_hist(obs=100);                        

proc freq data=interwrk.ever_parent_earn_fq_hist_stcnt;
    table sein_state /out=outputs.ever_parent_earn_fq_stcnt;
run;
